# Lupr - Lup Recorder

[![image](https://img.shields.io/pypi/v/lupr.svg)](https://pypi.org/project/lupv/)
[![image](https://img.shields.io/pypi/l/lupr.svg)](https://pypi.org/project/lupv/)
[![image](https://img.shields.io/pypi/pyversions/lupr.svg)](https://pypi.org/project/lupv/)

## Requirements

- [wmctrl](https://manpages.debian.org/stretch/wmctrl/wmctrl.1.en.html)
- [xprop](https://manpages.debian.org/stretch/x11-utils/xprop.1.en.html)

Both of them already included in most GNU/Linux distribution. And see [requirements.txt](requirements.txt)

## Platform

- GNU/Linux

## Installation

- Use binaries from releases tag.

## Usage

- You can watch the [screencast](https://youtu.be/E_1ZLqjUyc0) and [tutorial](https://www.youtube.com/watch?v=kMVZ0-XiypY)

## License

GPLv3




